#include "camera.h"
#include "input.h"
#include "program.h"
#include "spritesheet.h"
#include "sprite.h"
#include "tilemap.h"
#include <assert.h>

static Spritesheet* spr_player_standing = NULL;
static Sprite* player = NULL;
static Transform player_trans = IdentityTransform;

static Level* level = NULL;

static Vector cam_speed = ZeroVector;

static
void cam_move_h(int val) {
    cam_speed.x = val * 0.1f;
}
static
void cam_move_v(int val) {
    cam_speed.y = -val * 0.1f;
}

static
void play() {
    g_camera.fov = 40;
    spr_player_standing = spritesheet_load("assets/sprites/player.png", (IVector){128, 128});
    player = sprite_from_spritesheet(spr_player_standing, 0);
    player_trans.scale = (Vector){4.f, 4.f};
    sprite_set_origin(player, (Vector){0.25f, 1.f});

    level = level_load("level_0");

    input_add_axis_action(SDL_SCANCODE_LEFT, SDL_SCANCODE_RIGHT, &cam_move_h);
    input_add_axis_action(SDL_SCANCODE_DOWN, SDL_SCANCODE_UP, &cam_move_v);

}

static
void tick() {
    g_camera.transform.position = vaddf(g_camera.transform.position, cam_speed);
    player_trans.position = g_camera.transform.position;
}

static
void draw() {
    level_draw(level);
    sprite_draw(player, player_trans);
}

int main(int argc, char* argv[]) {
    struct ProgramSettings config = {
        .target_fps = 120,
        .title = "fencer",
        .view_resolution = {1920, 1080},
        .on_play = &play,
        .on_tick = &tick,
        .on_draw = &draw
    };
    return program_run(&config);
}
